import { Construct } from 'constructs';
export interface DataLandingZoneClientProps {
    readonly accountName: string;
    readonly region: string;
}
export interface DataLandingZoneClientBastionProps extends DataLandingZoneClientProps {
    readonly bastionName?: string;
}
export interface DataLandingZoneClientVpcIdProps extends DataLandingZoneClientProps {
    readonly vpcName: string;
}
export interface DataLandingZoneClientRouteTableIdProps extends DataLandingZoneClientProps {
    readonly vpcName: string;
    readonly routeTable: string;
}
export interface DataLandingZoneClientSubnetIdProps extends DataLandingZoneClientProps {
    readonly vpcName: string;
    readonly routeTable: string;
    readonly subnetName: string;
}
export declare class DataLandingZoneClient {
    /**
     * Fetches the bastion security group ID from the SSM Parameter Store
     *@param scope - The scope of the construct
     *@param id - The id of the construct
     *@param props - The props of the construct
     *@returns - The security group ID of the bastion
     */
    static bastionSecurityGroupId(scope: Construct, id: string, props: DataLandingZoneClientBastionProps): string;
    /**
     * Fetches the VPC ID from the SSM Parameter Store
     *@param scope - The scope of the construct
     *@param id - The id of the construct
     *@param props - The props of the construct
     *@returns - The ID of the VPC
     */
    static vpcId(scope: Construct, id: string, props: DataLandingZoneClientVpcIdProps): string;
    /**
     * Fetches the route table ID from the SSM Parameter Store
     *@param scope - The scope of the construct
     *@param id - The id of the construct
     *@param props - The props of the construct
     *@returns - The ID of the route table
     */
    static routeTableId(scope: Construct, id: string, props: DataLandingZoneClientRouteTableIdProps): string;
    /**
     * Fetches the subnet ID from the SSM Parameter Store
     *@param scope - The scope of the construct
     *@param id - The id of the construct
     *@param props - The props of the construct
     *@returns - The ID of the subnet
     */
    static subnetId(scope: Construct, id: string, props: DataLandingZoneClientSubnetIdProps): string;
    /**
     * Fetches the notification topic ARN from the SSM Parameter Store
     *@param scope - The scope of the construct
     *@param id - The id of the construct
     *@returns - The ARN of the notification topic
     */
    static notificationTopicArn(scope: Construct, id: string): string;
    /**
     * Fetches the permissions boundary ARN from the SSM Parameter Store
     *@param scope - The scope of the construct
     *@param id - The id of the construct
     *@returns - The ARN of the permissions boundary
     */
    static permissionsBoundaryArn(scope: Construct, id: string): string;
}
