import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { CreateInstanceAccessControlAttributeConfigurationRequest, CreateInstanceAccessControlAttributeConfigurationResponse } from "../models/models_0";
import { ServiceInputTypes, ServiceOutputTypes, SSOAdminClientResolvedConfig } from "../SSOAdminClient";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link CreateInstanceAccessControlAttributeConfigurationCommand}.
 */
export interface CreateInstanceAccessControlAttributeConfigurationCommandInput extends CreateInstanceAccessControlAttributeConfigurationRequest {
}
/**
 * @public
 *
 * The output of {@link CreateInstanceAccessControlAttributeConfigurationCommand}.
 */
export interface CreateInstanceAccessControlAttributeConfigurationCommandOutput extends CreateInstanceAccessControlAttributeConfigurationResponse, __MetadataBearer {
}
declare const CreateInstanceAccessControlAttributeConfigurationCommand_base: {
    new (input: CreateInstanceAccessControlAttributeConfigurationCommandInput): import("@smithy/smithy-client").CommandImpl<CreateInstanceAccessControlAttributeConfigurationCommandInput, CreateInstanceAccessControlAttributeConfigurationCommandOutput, SSOAdminClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: CreateInstanceAccessControlAttributeConfigurationCommandInput): import("@smithy/smithy-client").CommandImpl<CreateInstanceAccessControlAttributeConfigurationCommandInput, CreateInstanceAccessControlAttributeConfigurationCommandOutput, SSOAdminClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Enables the attributes-based access control (ABAC) feature for the specified IAM Identity Center
 *             instance. You can also specify new attributes to add to your ABAC configuration during
 *             the enabling process. For more information about ABAC, see <a href="/singlesignon/latest/userguide/abac.html">Attribute-Based Access Control</a> in the <i>IAM Identity Center User Guide</i>.</p>
 *          <note>
 *             <p>After a successful response, call
 *                     <code>DescribeInstanceAccessControlAttributeConfiguration</code> to validate
 *                 that <code>InstanceAccessControlAttributeConfiguration</code> was created.</p>
 *          </note>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { SSOAdminClient, CreateInstanceAccessControlAttributeConfigurationCommand } from "@aws-sdk/client-sso-admin"; // ES Modules import
 * // const { SSOAdminClient, CreateInstanceAccessControlAttributeConfigurationCommand } = require("@aws-sdk/client-sso-admin"); // CommonJS import
 * const client = new SSOAdminClient(config);
 * const input = { // CreateInstanceAccessControlAttributeConfigurationRequest
 *   InstanceArn: "STRING_VALUE", // required
 *   InstanceAccessControlAttributeConfiguration: { // InstanceAccessControlAttributeConfiguration
 *     AccessControlAttributes: [ // AccessControlAttributeList // required
 *       { // AccessControlAttribute
 *         Key: "STRING_VALUE", // required
 *         Value: { // AccessControlAttributeValue
 *           Source: [ // AccessControlAttributeValueSourceList // required
 *             "STRING_VALUE",
 *           ],
 *         },
 *       },
 *     ],
 *   },
 * };
 * const command = new CreateInstanceAccessControlAttributeConfigurationCommand(input);
 * const response = await client.send(command);
 * // {};
 *
 * ```
 *
 * @param CreateInstanceAccessControlAttributeConfigurationCommandInput - {@link CreateInstanceAccessControlAttributeConfigurationCommandInput}
 * @returns {@link CreateInstanceAccessControlAttributeConfigurationCommandOutput}
 * @see {@link CreateInstanceAccessControlAttributeConfigurationCommandInput} for command's `input` shape.
 * @see {@link CreateInstanceAccessControlAttributeConfigurationCommandOutput} for command's `response` shape.
 * @see {@link SSOAdminClientResolvedConfig | config} for SSOAdminClient's `config` shape.
 *
 * @throws {@link AccessDeniedException} (client fault)
 *  <p>You do not have sufficient access to perform this action.</p>
 *
 * @throws {@link ConflictException} (client fault)
 *  <p>Occurs when a conflict with a previous successful write is detected. This generally
 *             occurs when the previous write did not have time to propagate to the host serving the
 *             current request. A retry (with appropriate backoff logic) is the recommended response to
 *             this exception.</p>
 *
 * @throws {@link InternalServerException} (server fault)
 *  <p>The request processing has failed because of an unknown error, exception, or failure
 *             with an internal server.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>Indicates that a requested resource is not found.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>Indicates that the principal has crossed the throttling limits of the API
 *             operations.</p>
 *
 * @throws {@link ValidationException} (client fault)
 *  <p>The request failed because it contains a syntax error.</p>
 *
 * @throws {@link SSOAdminServiceException}
 * <p>Base exception class for all service exceptions from SSOAdmin service.</p>
 *
 * @public
 */
export declare class CreateInstanceAccessControlAttributeConfigurationCommand extends CreateInstanceAccessControlAttributeConfigurationCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: CreateInstanceAccessControlAttributeConfigurationRequest;
            output: {};
        };
        sdk: {
            input: CreateInstanceAccessControlAttributeConfigurationCommandInput;
            output: CreateInstanceAccessControlAttributeConfigurationCommandOutput;
        };
    };
}
